#
# spec file for package bison
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  xz
Requires(pre):  %install_info_prereq
# bug437293
%ifarch ppc64
Obsoletes:      bison-64bit
%endif
Version:        2.7
Release:        11.15
Summary:        The GNU Parser Generator
License:        GPL-3.0+
Group:          Development/Languages/C and C++
Url:            http://www.gnu.org/software/bison/bison.html
Source:         http://ftp.gnu.org/gnu/bison/bison-%{version}.tar.xz
Source2:        baselibs.conf
Requires:       m4
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Bison is a parser generator similar to yacc(1).

%prep
%setup -q

%build
%configure --disable-silent-rules --disable-rpath \
  gl_cv_func_printf_directive_n=yes \
  gl_cv_func_printf_infinite_long_double=yes
make %{?_smp_mflags}

%check
make %{?_smp_mflags} check

%install
%makeinstall
%find_lang %{name} --all-name

%files -f %{name}.lang
%defattr(-,root,root)
%doc COPYING ChangeLog NEWS README
%dir %{_datadir}/aclocal
%{_bindir}/bison
%{_bindir}/yacc
%{_libdir}/liby.a
%{_datadir}/bison
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/bison-i18n.m4
%doc %{_infodir}/bison.info*.gz
%doc %{_mandir}/man1/bison.1.gz
%doc %{_mandir}/man1/yacc.1.gz

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%changelog
* Tue Jul  9 2013 schwab@suse.de
- Override broken configure checks
* Thu Mar 21 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Wed Feb  6 2013 adrian@suse.com
- bison update to 2.7
  * Changes in the format of error messages
  * New format for error reports: carets
  * New value for %%define variable: api.pure full
  * New %%define variable: api.location.type (glr.cc, lalr1.cc, lalr1.java)
  * Exception safety (lalr1.cc)
  * Graph improvements in DOT and XSLT
  * %%language is no longer an experimental feature.
* Mon Nov 12 2012 crrodriguez@opensuse.org
- bison 2.6.5
  * Incorrect definitions of YY_, issued by yacc.c when no parser header is
  generated, are removed.
  * Fix compiler warnings in the generated parser (yacc.c, glr.c)
  * Warnings about uninitialized yylval and/or yylloc for push parsers with a
  pure interface have been fixed for GCC 4.0 up to 4.8, and Clang 2.9 to
  3.2.
* Sun Sep 23 2012 nmo.marques@gmail.com
- Update to version 2.6.2:
  + Buffer overruns, complaints from Flex, and portability issues
    in the test suite have been fixed.
  + Changelist too long to fit here, see NEWS
- Source format is now .xz
- Remove bison-stdio.in.patch: seems upstreamed
- Add 'xz' to BuildRequires
* Tue Jul 17 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Mon Jan  9 2012 aj@suse.de
- Own /usr/share/aclocal
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Tue Jun  7 2011 crrodriguez@opensuse.org
- Update to version 2.5
- Fixes GCC 4.6 warnings
- Changelist too long to fit here, see NEWS.
* Wed Feb 10 2010 rguenther@suse.de
- Update to version 2.4.1.
- Apply fix for GCC 4.5 compliance.
- Apply fix for unsupported output file names.
* Mon Feb  8 2010 coolo@novell.com
- package yacc.1 too
* Fri Jan 29 2010 coolo@novell.com
- fix patch name
* Tue Jan 26 2010 mmarek@suse.cz
- updated to 2.4
  * new experimental %%language directive to select the used
    skeleton and output file name
  * experimantal Java parser support
  * support for push parsers
  * bison now removes unreachable states (this might require
    updates to %%expect and %%expect-rr directives)
  * support for per-type and default %%destructor's and %%printer's
  * except for LALR(1) parsers in C with POSIX Yacc emulation enabled
    (with `-y', `--yacc', or `%%yacc'), Bison no longer generates
    [#]define statements for associating token numbers with token
    names
  * For a detailed list of fixes and new features, see
    /usr/share/doc/packages/bison/NEWS
* Sat Dec 12 2009 jengelh@medozas.de
- enable parallel building
- add baselibs.conf as a source
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Jan 24 2007 mmarek@suse.cz
- use more $RPM_OPT_FLAGS
* Mon Jun 26 2006 mmarek@suse.cz
- updated to 2.3
  * all generated scanners can be used in non-free programs
    (previously, only LALR(1) scanners in C had the exception)
  * multiple %%union declarations can be used, they will be
    concatenated
  * unused values with a %%destructor are warned about
  * %%destructors are not run for values in the action that called
    YYABORT/YYACCEPT/YYERROR
  * unsatisfied number of %%expect/%%expect-rr conflicts is an error,
    not warning
  * ability to depend on a minimal bison version via
    %%require "VERSION"
  * no global YYSTYPE and YYLTYPE macros and token names in C++
    scanners -- yy::parser::semantic_type, yy::parser::location_type
    and yy::parser::token::<token> should be used instead
    (can be reverted by '%%define "global_tokens_and_yystype" "1"')
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 21 2005 mmarek@suse.cz
- push the 2.1 update into factory
* Thu Dec 15 2005 mmarek@suse.cz
- update to 2.1
* Fri Nov  5 2004 tcrhak@suse.cz
- fixed wrong variable name (bug #47961, patch output)
* Mon Jan 26 2004 kukuk@suse.de
- Readd m4 requirement
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Tue Jan  6 2004 tcrhak@suse.cz
- update to version 1.875
- use %%{_libdir}
- run the testsuite
- applied Michael Matz's patch
- GCC does not support attributes on label in C++
* Fri Sep 12 2003 tcrhak@suse.cz
- require m4, issue an error message and return a non-zero
  exit code if m4 binary is not found [bug #30653], patch readpipe
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Fri Mar  7 2003 tcrhak@suse.cz
- Improved fix for the scaner: treat @ and initial comments
  the right way
* Fri Feb  7 2003 ro@suse.de
- added install_info macros
* Sat Nov  9 2002 aj@suse.de
- Fix one more problem encountered in building gcc with $
  (all work done by jh@suse.cz).
* Sat Nov  9 2002 aj@suse.de
- Fix last patch to handle $ in comments correctly.
* Sat Nov  9 2002 aj@suse.de
- Fix handling of $ in scan-gram.
* Wed Nov  6 2002 tcrhak@suse.cz
- update to version 1.75
- removed YYPARSE_RETURN_TYPE: no package uses this and yyparse()
  relies on having its return type compatible with int
- do not use C++ kludges fix with the new version
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Jul 23 2002 tcrhak@suse.cz
- a stack overflow fix for `C++ kludges': do extend stack
  even if location tracking is not enabled
* Wed Jun 26 2002 tcrhak@suse.cz
- update to 1.35
* Wed Feb 13 2002 schwab@suse.de
- Don't use NULL when it may not be defined.
* Fri Feb  8 2002 tcrhak@suse.cz
- update to version 1.33
* Fri Jan 25 2002 tcrhak@suse.cz
- update to version 1.32
* Tue Dec 11 2001 schwab@suse.de
- Fix double free.
* Fri Nov 30 2001 schwab@suse.de
- Fix use of YYSTACK_USE_ALLOCA in parser skeleton.
* Fri Nov 30 2001 tcrhak@suse.cz
- update to 1.30
* Sun Dec  3 2000 schwab@suse.de
- Fix line numbers in bison.simple.
* Thu Aug 24 2000 nadvornik@suse.cz
- update to 1.28
* Fri Jan 28 2000 schwab@suse.de
- Fix missing declaration
- Specfile cleanup, get rid of Makefile.Linux
- /usr/{info,man} -> /usr/share/{info,man}
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Jun 13 1997 rj@suse.de
- yacc emulation removed, because of existing mid-age technology
* Fri May 16 1997 rj@suse.de
- version 1.25
  - yacc-functionality emulated thru script
